@@ -53,7 +53,7 @@ from neuralspace.constants import (
     TRAINING_STATUS,
     TRAINING_TIME,
     TYPE,
-    neuralspace_url, UPLOAD_DATASET_COMMAND,
+    neuralspace_url, UPLOAD_DATASET_COMMAND, INITIATED, QUEUED, START_INDEX, END_INDEX,
 )
 from neuralspace.nlu.constants import (
     CREATE_EXAMPLE_URL,
@@ -68,9 +68,9 @@ from neuralspace.nlu.constants import (
     LIST_PROJECTS_URL,
     PARSE_URL,
     SINGLE_MODEL_DETAILS_URL,
-    TRAIN_MODEL_URL,
+    TRAIN_MODEL_URL, C_COMPLETED, C_QUEUED, C_INITIATED, C_DEAD, C_TIMED_OUT, C_FAILED,
 )
-from neuralspace.utils import get_auth_token, is_success_status
+from neuralspace.utils import get_auth_token, is_success_status, print_ner_response
 
 logger = logging.getLogger(__name__)
 console = Console()
@@ -172,38 +172,20 @@ def print_projects_table(projects: Dict[Text, Any]):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
     table.add_column("Project Name", style="#c47900")
     table.add_column("Project ID", style="#c47900")
+    table.add_column("Number of Examples", style="#c47900")
     table.add_column("Number of Intents", style="#c47900")
-    table.add_row(
-        "[bold]Login[/bold]",
-        "neuralspace [bold red]login[/bold red]",
-        "Login to the our platform and save credentials locally",
-    )
-    table.add_row(
-        "[bold]List Apps[/bold]",
-        "neuralspace [bold red]list-apps[/bold red]",
-        "List all the available apps in our platform and their respective codes",
-    )
-    table = PrettyTable()
-    table.field_names = [
-        "Project Name",
-        "Project ID",
-        "Number of Examples",
-        "Number of Intents",
-        "number of Models",
-        "Languages",
-    ]
+    table.add_column("Number of Models", style="#c47900")
+    table.add_column("Languages", style="#c47900")
     for data in projects[DATA][PROJECTS]:
         table.add_row(
-            [
                 data[PROJECT_NAME],
                 data[PROJECT_ID],
                 data[NUMBER_OF_EXAMPLES],
                 data[NUMBER_OF_INTENTS],
                 data[NUMBER_OF_MODELS],
-                data[LANGUAGE],
-            ]
+                data[LANGUAGE]
         )
-    logger.info(f"\n{table}")
+    console.print(table)
 
 
 def train_table(projects: Dict[Text, Any]):
@@ -253,21 +235,26 @@ async def list_projects(
             )
             print_projects_table(json_response)
         else:
-            logger.error("Failed to list projects")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            console.print("> [red]ERROR[/red] ❌ Failed to list projects")
+            console.print(f"Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
 def print_examples_table(examples: Dict[Text, Any]):
-    table = PrettyTable()
-    table.field_names = ["Example ID", "Text", "Intent", "N Entities"]
-    logger.info(f"Total Examples Count: {examples[DATA][COUNT]}")
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table.add_column("Example ID", style="#c47900")
+    table.add_column("Text", style="#c47900")
+    table.add_column("Intent", style="#c47900")
+    table.add_column("N Entities", style="#c47900")
+
+    logger.info(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Examples Count: {examples[DATA][COUNT]}")
     for data in examples[DATA][EXAMPLES]:
         text = data[TEXT][:20]
         if len(data[TEXT]) > 20:
             text = f"{text}..."
-        table.add_row([data[EXAMPLE_ID], text, data[INTENT], len(data[ENTITIES])])
-    logger.info(f"\n{table}")
+        table.add_row(data[EXAMPLE_ID], text, data[INTENT], len(data[ENTITIES]))
+
+    console.print(table)
 
 
 async def list_examples(
@@ -279,9 +266,12 @@ async def list_examples(
     page_number: int,
     page_size: int,
 ) -> Dict[Text, Any]:
-    logger.info(
-        f"Fetching Examples with filter: Project ID: {project_id}; Language: {language}; "
-        f"Prepared: {prepared}; type: {type}"
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching Examples with filter: \n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] #️⃣ [bold]Project ID:[/bold] [orange]{project_id}[orange]"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✏️ Language: {language}; "
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🍲 Prepared: {prepared}; "
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📌 type: {type}"
     )
     payload = {
         FILTER: {
@@ -307,31 +297,44 @@ async def list_examples(
         if is_success_status(response.status):
             print_examples_table(json_response)
         else:
-            logger.error("Failed to list examples")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            console.print("> [red]ERROR[/red] ❌ Failed to list examples")
+            console.print(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
-def print_models_table(models: Dict[Text, Any]):
+def get_training_status_colour(status: Text) -> Text:
+    if status == COMPLETED:
+        return C_COMPLETED
+    elif status == FAILED:
+        return C_FAILED
+    elif status == TIMED_OUT:
+        return C_TIMED_OUT
+    elif status == DEAD:
+        return C_DEAD
+    elif status == INITIATED:
+        return C_INITIATED
+    elif status == QUEUED:
+        return C_QUEUED
 
-    table = PrettyTable()
-    table.field_names = [
-        "Model ID",
-        "Model Name",
-        "Training Status",
-        "Replicas",
-        "Intent Acc",
-        "Entity Acc",
-        "Training Time (sec)",
-        "Last Updated",
-    ]
-    logger.info(f"Total Models Count: {models[DATA][COUNT]}")
+
+def print_models_table(models: Dict[Text, Any]):
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table.add_column("Model ID", style="#c47900")
+    table.add_column("Model Name", style="#c47900")
+    table.add_column("Training Status", style="#c47900")
+    table.add_column("Intent Acc", style="#c47900")
+    table.add_column("Entity Acc", style="#c47900")
+    table.add_column("Training Time (sec)", style="#c47900")
+    table.add_column("Last Updated", style="#c47900")
+
+    console.print(f"> Total Models Count: {models[DATA][COUNT]}")
+    logger.info(f" [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}")
     for data in models[DATA][MODELS]:
         table.add_row(
-            [
+
                 data[MODEL_ID],
                 data[MODEL_NAME],
-                data[TRAINING_STATUS],
+                f"{get_training_status_colour(data[TRAINING_STATUS])} {data[TRAINING_STATUS]}",
                 data[REPLICAS],
                 "{:.3f}".format(
                     data[METRICS][INTENT_CLASSIFIER_METRICS][INTENT_ACCURACY]
@@ -343,9 +346,9 @@ def print_models_table(models: Dict[Text, Any]):
                 else 0.0,
                 data[TRAINING_TIME] if data[TRAINING_STATUS] == COMPLETED else 0.0,
                 data[LAST_STATUS_UPDATED],
-            ]
+
         )
-    logger.info(f"\n{table}")
+    console.print(table)
 
 
 async def list_models(
@@ -356,8 +359,10 @@ async def list_models(
     page_size: int,
 ) -> Dict[Text, Any]:
     console.print(
-        f"Fetching models with filter: Project ID: {project_id}; Language: {language}; "
-        f"Training Statuses: {training_status}"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching models with filter: \n"
+        f"#️⃣ Project ID: {project_id}; "
+        f"✏️ Language: {language}; "
+        f"🏋️ Training Statuses: {training_status}"
     )
     payload = {
         FILTER: {PROJECT_ID: project_id, LANGUAGE: language},
@@ -378,13 +383,13 @@ async def list_models(
         if is_success_status(response.status):
             print_models_table(json_response)
         else:
-            logger.error("Failed to list models")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            logger.error("> [red]ERROR[/red] ❌ Failed to list models")
+            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
 async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
-    logger.info(f"Deleting Example with id: {example_ids}")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting Example with id: {example_ids}")
     payload = {EXAMPLE_ID: example_ids}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -395,10 +400,10 @@ async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.info(f"Platform Response: \n{json.dumps(json_response, indent=4)}")
+            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted example!")
         else:
-            logger.error("Failed to delete examples")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            logger.error("> [red]ERROR[/red] ❌ Failed to delete examples")
+            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
@@ -540,7 +545,7 @@ async def train_model(
 
 
 async def delete_models(model_id: Text) -> Dict[Text, Any]:
-    logger.info(f"Deleting model with id: {model_id}")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting model with id: {model_id}")
     payload = {MODEL_ID: model_id}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -551,15 +556,15 @@ async def delete_models(model_id: Text) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.info(f"Platform Response: \n{json.dumps(json_response, indent=4)}")
+            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted model")
         else:
-            logger.error("Failed to delete models")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            console.print("> [red]ERROR[/red] ❌ Failed to delete models")
+            console.print(f"> Platform response: \n {json.dumps(json_response, indent=4)}")
     return json_response
 
 
 async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
-    logger.info(f"Deploying: Model ID: {model_id}; Replicas: {n_replicas};")
+    logger.info(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⤴️ Deploying: Model ID: {model_id}; Replicas: {n_replicas};")
     payload = {MODEL_ID: model_id, N_REPLICAS: n_replicas}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -571,53 +576,48 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.info("Model deployed successfully")
-            logger.info(f"Platform Response: \n{json.dumps(json_response, indent=4)}")
+            logger.info("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Model deployed successfully")
+            logger.info(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Platform Response: \n{json.dumps(json_response, indent=4)}")
         else:
-            logger.error("Failed to deploy model")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            logger.error("> [red]ERROR[/red] ❌ Failed to deploy model")
+            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
 def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
-    table = PrettyTable()
-    table.field_names = [
-        "Text",
-        "Intent",
-        "Intent Confidence",
-        "Entities[type|value|start-idx:end-idx]",
-        "Response Time (sec)",
-    ]
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table.add_column("Text", style="#c47900")
+    table.add_column("Intent", style="#c47900")
+    table.add_column("Intent Confidence", style="#c47900")
+    table.add_column("Response Time (sec)", style="#c47900")
     table.add_row(
-        [
             nlu_response[DATA]["text"][:30] + "[...]",
             nlu_response[DATA]["intent"]["name"],
             nlu_response[DATA]["intent"]["confidence"],
-            "; ".join(
-                [
-                    f"{e['entity']}|{e['value']}|{e['start']}:{e['end']} "
-                    for e in nlu_response[DATA]["entities"]
-                ]
-            ),
-            response_time / 1000,
-        ]
+            str(response_time / 1000),
     )
-    logger.info(f"\n{table}")
-    intent_ranking_table = PrettyTable()
-    intent_ranking_table.field_names = ["Intent", "Confidence"]
+    console.print(table)
+    intent_ranking_table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table.add_column("Intent", style="#c47900")
+    table.add_column("Confidence", style="#c47900")
 
     for row in nlu_response[DATA]["intent_ranking"]:
         intent_ranking_table.add_row(
-            [
                 row["name"],
                 row["confidence"],
-            ]
         )
-    logger.info(f"\nIntent Ranking \n{intent_ranking_table}")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Intent Ranking")
+    console.print(intent_ranking_table)
+    formatted_entities = []
+    for e in nlu_response["data"]["entities"]:
+        e[START_INDEX] = e["start"]
+        e[END_INDEX] = e["end"]
+        formatted_entities.append(e)
+    print_ner_response(formatted_entities, nlu_response["data"]["text"])
 
 
 async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
-    logger.info(f"Parsing text: {input_text}, using Model ID: {model_id}")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📝 Parsing text: {input_text}, using Model ID: {model_id}")
     payload = {MODEL_ID: model_id, DATA: {TEXT: input_text}}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -632,11 +632,9 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
         response_time = (end - start).microseconds
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.debug(
-                f"Platform Response: \n{json.dumps(json_response, indent=4, ensure_ascii=False)}"
-            )
+            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully parsed text")
             print_nlu_response(json_response, response_time)
         else:
-            logger.error("Failed to parse model")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            logger.error("> [red]ERROR[/red] ❌ Failed to parse model")
+            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
