@@ -84,3 +84,13 @@ SUPPORTED_LANGUAGES = [
     "ru",
     "es",
 ]
+
+
+
+# Training status colour codes
+C_INITIATED = "⚪"
+C_QUEUED = "🟠"
+C_COMPLETED = "🟢"
+C_FAILED = "🔴"
+C_TIMED_OUT = "🟤"
+C_DEAD = "⚫"
